operate with BiocFileCache to retrieve zip file of plink example data
Source:R/cache_example.R
get_plink_example_path.Rdoperate with BiocFileCache to retrieve zip file of plink example data
Usage
get_plink_example_path(ca = BiocFileCache::BiocFileCache())